@@ -572,7 +572,7 @@ static void dump_string_array(grib_dumper* d, grib_accessor* a, const char* comm
 
     values = (char**)grib_context_malloc_clear(c, size * sizeof(char*));
     if (!values) {
-        grib_context_log(c, GRIB_LOG_FATAL, "Memory allocation error: %zu bytes", size);
+        grib_context_log(c, GRIB_LOG_ERROR, "Memory allocation error: %zu bytes", size);
         return;
     }
 
