@@ -11,8 +11,6 @@
 #include "grib_api_internal.h"
 #include <float.h>
 
-#define STR_EQUAL(s1, s2) (strcmp((s1), (s2)) == 0)
-
 typedef enum
 {
     eROUND_ANGLE_UP,
@@ -810,7 +808,7 @@ static const char* get_grid_type_name(const int spec_grid_type)
 
 static int is_constant_field(const double missingValue, const double* data_values, size_t data_values_count)
 {
-    int ii       = 0;
+    size_t ii    = 0;
     int constant = 1;
     double value = missingValue;
 
@@ -982,8 +980,8 @@ grib_handle* grib_util_set_spec2(grib_handle* h,
         fprintf(stderr, "ECCODES DEBUG grib_util: input_decimal_scale_factor = %ld\n", input_decimal_scale_factor);
     }
 
-    /* ECC-1201
-       TODO: make sure input packing type is preserved */
+    /* ECC-1201, ECC-1529, ECC-1530
+       Make sure input packing type is preserved */
     if (packing_spec->packing == GRIB_UTIL_PACKING_SAME_AS_INPUT &&
         packing_spec->packing_type == GRIB_UTIL_PACKING_TYPE_SAME_AS_INPUT)
     {
@@ -1161,22 +1159,22 @@ grib_handle* grib_util_set_spec2(grib_handle* h,
             COPY_SPEC_DOUBLE(latitudeOfFirstGridPointInDegrees);
             COPY_SPEC_LONG(Ni); /* same as Nx */
             COPY_SPEC_LONG(Nj); /* same as Ny */
-            /* TODO: pass in extra keys e.g. Dx, Dy, standardParallel and centralLongitude */
+            COPY_SPEC_LONG(iScansNegatively);
+            COPY_SPEC_LONG(jScansPositively);
 
-            /*
-            COPY_SPEC_LONG(DxInMetres);
-            COPY_SPEC_LONG(DyInMetres);
-            COPY_SPEC_LONG(xDirectionGridLengthInMillimetres);
-            COPY_SPEC_LONG(yDirectionGridLengthInMillimetres);
-            COPY_SPEC_LONG(standardParallelInMicrodegrees);
-            COPY_SPEC_LONG(centralLongitudeInMicrodegrees);
-            */
+            // TODO(masn): pass in extra keys e.g. Dx, Dy, standardParallel and centralLongitude
+            // COPY_SPEC_LONG(DxInMetres);
+            // COPY_SPEC_LONG(DyInMetres);
+            // COPY_SPEC_LONG(xDirectionGridLengthInMillimetres);
+            // COPY_SPEC_LONG(yDirectionGridLengthInMillimetres);
+            // COPY_SPEC_LONG(standardParallelInMicrodegrees);
+            // COPY_SPEC_LONG(centralLongitudeInMicrodegrees);
 
             break;
         case GRIB_UTIL_GRID_SPEC_UNSTRUCTURED:
             COPY_SPEC_LONG(bitmapPresent);
             if (spec->missingValue) COPY_SPEC_DOUBLE(missingValue);
-            /* TODO: Other keys */
+            /* TODO(masn): Other keys */
             break;
         case GRIB_UTIL_GRID_SPEC_LAMBERT_CONFORMAL:
             COPY_SPEC_LONG(bitmapPresent);
@@ -1186,11 +1184,16 @@ grib_handle* grib_util_set_spec2(grib_handle* h,
             COPY_SPEC_LONG(Ni); /* same as Nx */
             COPY_SPEC_LONG(Nj); /* same as Ny */
 
-            /*
-             * Note: DxInMetres and DyInMetres
-             * should be 'double' and not integer. WMO GRIB2 uses millimetres!
-             * TODO: Add other keys like Latin1, LoV etc
-            */
+            COPY_SPEC_LONG(iScansNegatively);
+            COPY_SPEC_LONG(jScansPositively);
+            COPY_SPEC_DOUBLE(latitudeOfSouthernPoleInDegrees);
+            COPY_SPEC_DOUBLE(longitudeOfSouthernPoleInDegrees);
+            COPY_SPEC_LONG(uvRelativeToGrid);
+
+            // Note: DxInMetres and DyInMetres
+            // should be 'double' and not integer. WMO GRIB2 uses millimetres!
+            // TODO(masn): Add other keys like Latin1, LoV etc
+
             break;
 
         case GRIB_UTIL_GRID_SPEC_REDUCED_GG:
@@ -1286,7 +1289,7 @@ grib_handle* grib_util_set_spec2(grib_handle* h,
                  * Reason 1: It is not available in GRIB1 and so we have to wait until we change edition
                  * Reason 2: It has to be done AFTER we set the data values
                  */
-                if (strcmp(input_packing_type, "grid_jpeg") && !strcmp(input_packing_type, "grid_simple"))
+                if (strcmp(input_packing_type, "grid_jpeg"))
                     setJpegPacking = 1;
                 break;
             case GRIB_UTIL_PACKING_TYPE_CCSDS:
@@ -1629,7 +1632,7 @@ cleanup:
         grib_handle_delete(h_out);
     return NULL;
 }
-
+#if 0
 int grib_moments(grib_handle* h, double east, double north, double west, double south, int order, double* moments, long* count)
 {
     grib_iterator* iter = NULL;
@@ -1716,8 +1719,9 @@ int grib_moments(grib_handle* h, double east, double north, double west, double
 
     return ret;
 }
+#endif
 
-/* Helper function for 'parse_keyval_string' */
+// Helper function for 'parse_keyval_string'
 static void set_value(grib_values* value, char* str, int equal)
 {
     char *p = 0, *q = 0, *s = 0;
@@ -1803,14 +1807,14 @@ static void set_value(grib_values* value, char* str, int equal)
     }
 }
 
-/*
- 'grib_tool'        Optional tool name which is printed on error. Can be NULL
- 'arg'              The string to be parsed e.g. key1=value1,key2!=value2 etc (cannot be const)
- 'values_required'  If true then each key must have a value after it
- 'default_type'     The default type e.g. GRIB_TYPE_UNDEFINED or GRIB_TYPE_DOUBLE
- 'values'           The array we populate and return (output)
- 'count'            Number of elements (output). Must be initialised to the size of the values array
- */
+//
+//  'grib_tool'        Optional tool name which is printed on error. Can be NULL
+//  'arg'              The string to be parsed e.g. key1=value1,key2!=value2 etc (cannot be const)
+//  'values_required'  If true then each key must have a value after it
+//  'default_type'     The default type e.g. GRIB_TYPE_UNDEFINED or GRIB_TYPE_DOUBLE
+//  'values'           The array we populate and return (output)
+//  'count'            Number of elements (output). Must be initialised to the size of the values array
+//
 int parse_keyval_string(const char* grib_tool,
                         char* arg, int values_required, int default_type,
                         grib_values values[], int* count)
@@ -1891,18 +1895,22 @@ int parse_keyval_string(const char* grib_tool,
     return GRIB_SUCCESS;
 }
 
-/* Return 1 if the productDefinitionTemplateNumber (GRIB2) is related to EPS */
+// Return 1 if the productDefinitionTemplateNumber (GRIB2) is for EPS (ensemble) products
 int grib2_is_PDTN_EPS(long pdtn)
 {
-    return (
-        pdtn == 1 || pdtn == 11 ||
-        pdtn == 33 || pdtn == 34 || /*simulated (synthetic) satellite data*/
-        pdtn == 41 || pdtn == 43 || /*atmospheric chemical constituents*/
-        pdtn == 45 || pdtn == 47 || pdtn == 85  /*aerosols*/
-    );
+#define NUMBER(x) (sizeof(x) / sizeof(x[0]))
+
+    static int eps_pdtns[] = { 1, 11, 33, 34, 41, 43, 45, 47,
+                               49, 54, 56, 58, 59, 60, 61, 63, 68, 71, 73, 77, 79,
+                               81, 83, 84, 85, 92, 94, 96, 98 };
+    size_t i;
+    for (i = 0; i < NUMBER(eps_pdtns); ++i) {
+        if (eps_pdtns[i] == pdtn) return 1;
+    }
+    return 0;
 }
 
-/* Return 1 if the productDefinitionTemplateNumber (GRIB2) is for atmospheric chemical constituents */
+// Return 1 if the productDefinitionTemplateNumber (GRIB2) is for atmospheric chemical constituents
 int grib2_is_PDTN_Chemical(long pdtn)
 {
     return (
@@ -1912,8 +1920,8 @@ int grib2_is_PDTN_Chemical(long pdtn)
         pdtn == 43);
 }
 
-/* Return 1 if the productDefinitionTemplateNumber (GRIB2) is for
- * atmospheric chemical constituents with source or sink */
+// Return 1 if the productDefinitionTemplateNumber (GRIB2) is for
+// atmospheric chemical constituents with source or sink
 int grib2_is_PDTN_ChemicalSourceSink(long pdtn)
 {
     return (
@@ -1923,8 +1931,8 @@ int grib2_is_PDTN_ChemicalSourceSink(long pdtn)
         pdtn == 79);
 }
 
-/* Return 1 if the productDefinitionTemplateNumber (GRIB2) is for
- * atmospheric chemical constituents based on a distribution function */
+// Return 1 if the productDefinitionTemplateNumber (GRIB2) is for
+// atmospheric chemical constituents based on a distribution function
 int grib2_is_PDTN_ChemicalDistFunc(long pdtn)
 {
     return (
@@ -1934,11 +1942,11 @@ int grib2_is_PDTN_ChemicalDistFunc(long pdtn)
         pdtn == 68);
 }
 
-/* Return 1 if the productDefinitionTemplateNumber (GRIB2) is for aerosols */
+// Return 1 if the productDefinitionTemplateNumber (GRIB2) is for aerosols
 int grib2_is_PDTN_Aerosol(long pdtn)
 {
-    /* Notes: PDT 44 is deprecated and replaced by 48 */
-    /*        PDT 47 is deprecated and replaced by 85 */
+    // Notes: PDT 44 is deprecated and replaced by 48
+    //        PDT 47 is deprecated and replaced by 85
     return (
         pdtn == 44 ||
         pdtn == 48 ||
@@ -1949,23 +1957,21 @@ int grib2_is_PDTN_Aerosol(long pdtn)
         pdtn == 85);
 }
 
-/* Return 1 if the productDefinitionTemplateNumber (GRIB2) is for optical properties of aerosol */
+// Return 1 if the productDefinitionTemplateNumber (GRIB2) is for optical properties of aerosol
 int grib2_is_PDTN_AerosolOptical(long pdtn)
 {
-    /* Note: PDT 48 can be used for both plain aerosols as well as optical properties of aerosol.
-     * For the former user must set the optical wavelength range to missing.
-     */
+    // Note: PDT 48 can be used for both plain aerosols as well as optical properties of aerosol.
+    // For the former user must set the optical wavelength range to missing
     return (
         pdtn == 48 ||
         pdtn == 49);
 }
 
-/* Given some information about the type of grib2 parameter, return the productDefinitionTemplateNumber to use.
- * All arguments are booleans (0 or 1)
- * is_eps:     ensemble or deterministic
- * is_instant: instantaneous or interval-based
- * etc
- */
+// Given some information about the type of grib2 parameter, return the productDefinitionTemplateNumber to use.
+// All arguments are booleans (0 or 1)
+//  is_eps:     ensemble or deterministic
+//  is_instant: instantaneous or interval-based
+//  etc...
 int grib2_select_PDTN(int is_eps, int is_instant,
                       int is_chemical,
                       int is_chemical_srcsink,
@@ -1973,8 +1979,8 @@ int grib2_select_PDTN(int is_eps, int is_instant,
                       int is_aerosol,
                       int is_aerosol_optical)
 {
-    /* At most one has to be set. All could be 0 */
-    /* Unfortunately if PDTN=48 then both aerosol and aerosol_optical can be 1! */
+    // At most one has to be set. All could be 0
+    // Unfortunately if PDTN=48 then both aerosol and aerosol_optical can be 1!
     const int sum = is_chemical + is_chemical_srcsink + is_chemical_distfn + is_aerosol + is_aerosol_optical;
     Assert(sum == 0 || sum == 1 || sum == 2);
 
@@ -2027,12 +2033,12 @@ int grib2_select_PDTN(int is_eps, int is_instant,
         if (is_eps) {
             if (is_instant)
                 return 49;
-            /* WMO does not have a non-instantaneous case here! */
+            // WMO does not have a non-instantaneous case here!
         }
         else {
             if (is_instant)
                 return 48;
-            /* WMO does not have a non-instantaneous case here! */
+            // WMO does not have a non-instantaneous case here!
         }
     }
 
@@ -2041,17 +2047,17 @@ int grib2_select_PDTN(int is_eps, int is_instant,
             if (is_instant)
                 return 45;
             else
-                return 85; /* PDT 47 is deprecated*/
+                return 85; // PDT 47 is deprecated
         }
         else {
             if (is_instant)
-                return 48; /*44 is deprecated*/
+                return 48; // 44 is deprecated
             else
                 return 46;
         }
     }
 
-    /* Fallthru case: default */
+    // Fallthru case: default
     if (is_eps) {
         if (is_instant)
             return 1;
@@ -2099,7 +2105,7 @@ int grib_check_data_values_range(grib_handle* h, const double min_val, const dou
         return GRIB_ENCODING_ERROR;
     }
 
-    /* Data Quality checks */
+    // Data Quality checks
     if (ctx->grib_data_quality_checks) {
         result = grib_util_grib_data_quality_check(h, min_val, max_val);
     }
@@ -2107,10 +2113,10 @@ int grib_check_data_values_range(grib_handle* h, const double min_val, const dou
     return result;
 }
 
-/* Return true(1) if large constant fields are to be created, otherwise false(0) */
+// Return true(1) if large constant fields are to be created, otherwise false(0)
 int grib_producing_large_constant_fields(grib_handle* h, int edition)
 {
-    /* First check if the transient key is set */
+    // First check if the transient key is set
     grib_context* c                 = h->context;
     long produceLargeConstantFields = 0;
     if (grib_get_long(h, "produceLargeConstantFields", &produceLargeConstantFields) == GRIB_SUCCESS &&
@@ -2122,7 +2128,7 @@ int grib_producing_large_constant_fields(grib_handle* h, int edition)
         return 1;
     }
 
-    /* Finally check the environment variable via the context */
+    // Finally check the environment variable via the context
     return c->large_constant_fields;
 }
 
@@ -2133,18 +2139,26 @@ int grib_util_grib_data_quality_check(grib_handle* h, double min_val, double max
     double min_field_value_allowed = 0, max_field_value_allowed = 0;
     long paramId           = 0;
     grib_context* ctx      = h->context;
-    int is_error           = 1;
+    bool is_error          = true;
     char description[1024] = {0,};
-    char step[32] = "unknown";
-    size_t len    = 32;
-    /*
-     * If grib_data_quality_checks == 1, limits failure results in an error
-     * If grib_data_quality_checks == 2, limits failure results in a warning
-     */
+    char step[32]          = "unknown";
+    char shortName[32]     = {0,};
+    size_t len             = 32;
+
+    // If grib_data_quality_checks == 1, limits failure results in an error
+    // If grib_data_quality_checks == 2, limits failure results in a warning
+
     Assert(ctx->grib_data_quality_checks == 1 || ctx->grib_data_quality_checks == 2);
     is_error = (ctx->grib_data_quality_checks == 1);
 
-    /* The limit keys must exist if we are here */
+    err = grib_get_string(h, "shortName", shortName, &len);
+    if (err || STR_EQUAL(shortName, "unknown")) {
+        fprintf(stderr, "ECCODES %s   :  Invalid metadata: shortName=unknown\n",
+                    (is_error ? "ERROR" : "WARNING"));
+        if (is_error) return GRIB_INVALID_MESSAGE;
+    }
+
+    // The limit keys must exist if we are here
     err = grib_get_double(h, "param_value_min", &min_field_value_allowed);
     if (err) {
         grib_context_log(ctx, GRIB_LOG_ERROR, "grib_data_quality_check: Could not get param_value_min");
@@ -2178,7 +2192,7 @@ int grib_util_grib_data_quality_check(grib_handle* h, double min_val, double max
             }
         }
         if (is_error) {
-            return GRIB_OUT_OF_RANGE; /* Failure */
+            return GRIB_OUT_OF_RANGE; // Failure
         }
     }
     if (max_val > max_field_value_allowed) {
@@ -2194,7 +2208,7 @@ int grib_util_grib_data_quality_check(grib_handle* h, double min_val, double max
             }
         }
         if (is_error) {
-            return GRIB_OUT_OF_RANGE; /* Failure */
+            return GRIB_OUT_OF_RANGE; // Failure
         }
     }
 
