@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright 2005-2018 ECMWF.
+# (C) Copyright 2005- ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -8,15 +8,15 @@
 # virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
 #
 
-. ./include.sh
+. ./include.ctest.sh
 
 REDIRECT=/dev/null
 
-this_test="octa_grid.test"
-temp=temp.$this_test
+label="grib_octahedral_test"
+temp=temp.$label.txt
 
 # All our current GRIB samples (with reduced gaussian grids) are NON-Octahedral
-for s in $ECCODES_SAMPLES_PATH/reduced_gg_pl*tmpl; do
+for s in $ECCODES_SAMPLES_PATH/reduced_gg_pl*.tmpl; do
     grib_check_key_equals $s "isOctahedral" "0"
 done
 
@@ -27,9 +27,12 @@ grib_check_key_equals $input "global,isOctahedral" "1 1"
 # Check numberOfDataPoints
 grib_check_key_equals $input "numberOfDataPoints,numberOfCodedValues" "6599680 6599680"
 
-# Iterator
-${tools_dir}/grib_get_data $input > $temp
-numlines=`wc -l $temp | awk '{print $1}'`
-[ "$numlines" = "6599681" ]     # 1 + numberOfDataPoints
+
+# Only do lengthy iterator test if extra tests are enabled
+if [ $HAVE_EXTRA_TESTS -eq 1 ]; then
+    ${tools_dir}/grib_get_data $input > $temp
+    numlines=`wc -l $temp | awk '{print $1}'`
+    [ "$numlines" = "6599681" ]     # 1 + numberOfDataPoints
+fi
 
 rm -f $temp
